@@ -36,6 +36,7 @@ use {
         },
     },
     toastfile::{default_task_mount_readonly, location, user, DEFAULT_USER},
+    typed_path::UnixPath,
 };
 
 #[macro_use]
@@ -68,6 +69,7 @@ const LIST_OPTION: &str = "list";
 const SHELL_OPTION: &str = "shell";
 const TASKS_OPTION: &str = "tasks";
 const FORCE_OPTION: &str = "force";
+const FORCE_ALL_OPTION: &str = "force-all";
 const OUTPUT_DIR_OPTION: &str = "output-dir";
 
 // Set up the logger.
@@ -164,6 +166,7 @@ pub struct Settings {
     spawn_shell: bool,
     tasks: Option<Vec<String>>,
     forced_tasks: Vec<String>,
+    force_all: bool,
     output_dir: PathBuf,
 }
 
@@ -255,6 +258,11 @@ fn settings() -> Result<Settings, Failure> {
                 .help("Runs a task unconditionally, even if it\u{2019}s cached")
                 .multiple(true),
         )
+        .arg(
+            Arg::with_name(FORCE_ALL_OPTION)
+                .long(FORCE_ALL_OPTION)
+                .help("Pulls the base image and runs all tasks unconditionally"),
+        )
         .arg(
             Arg::with_name(TASKS_OPTION)
                 .value_name("TASKS")
@@ -385,6 +393,9 @@ fn settings() -> Result<Settings, Failure> {
                 .collect::<Vec<_>>()
         });
 
+    // Read the force all switch.
+    let force_all = matches.is_present(FORCE_ALL_OPTION);
+
     Ok(Settings {
         toastfile_path,
         docker_cli,
@@ -397,6 +408,7 @@ fn settings() -> Result<Settings, Failure> {
         spawn_shell,
         tasks,
         forced_tasks,
+        force_all,
         output_dir,
     })
 }
@@ -536,8 +548,9 @@ fn run_tasks(
 ) -> (Result<(), Failure>, Option<runner::Context>, Option<String>) {
     // This variable will be `true` as long as we're executing tasks that have `cache: true`. As
     // soon as we encounter a task with `cache: false`, this variable will be permanently set to
+    // `false`. If the user provided the `--force-image-pull` flag, this variable will always be
     // `false`.
-    let mut caching_enabled = true;
+    let mut caching_enabled = !settings.force_all;
 
     // We start with the base image.
     let mut context = Some(runner::Context {
@@ -580,6 +593,7 @@ fn run_tasks(
             toastfile,
             task_data,
             caching_enabled,
+            settings.force_all && i == 0,
             context.unwrap(), // Safe due to [ref:context_needed_if_not_final_task].
             need_context || i != schedule.len() - 1, // [tag:context_needed_if_not_final_task]
         );
@@ -750,9 +764,9 @@ fn entry() -> Result<(), Failure> {
                 // There is no last task, so the context will be the base image. Use default
                 // settings.
                 (
-                    HashMap::default(),        // [ref:default_environment]
-                    Path::new("/").to_owned(), // `toastfile::DEFAULT_LOCATION` might not exist.
-                    Vec::default(),            // [ref:default_mount_paths]
+                    HashMap::default(),            // [ref:default_environment]
+                    UnixPath::new("/").to_owned(), // `toastfile::DEFAULT_LOCATION` might not exist.
+                    Vec::default(),                // [ref:default_mount_paths]
                     default_task_mount_readonly(),
                     Vec::default(), // [ref:default_ports]
                     DEFAULT_USER.to_owned(),
